# Slack changelog

## [0.1.3] - 2026-01-15
- Updated connector definition (YAML version 0.1.1)
- Source commit: fa9a3b02
- SDK version: 0.1.0

## [0.1.2] - 2026-01-15
- Updated connector definition (YAML version 0.1.1)
- Source commit: 61a2e822
- SDK version: 0.1.0

## [0.1.1] - 2026-01-15
- Updated connector definition (YAML version 0.1.1)
- Source commit: 35211193
- SDK version: 0.1.0

## [0.1.0] - 2026-01-15
- Updated connector definition (YAML version 0.1.1)
- Source commit: 8b64ece5
- SDK version: 0.1.0
